@@ -513,13 +513,19 @@ def get_parser(version_string="Version: {vers} "
                                " of variants with MQ less than 40."
                                " Default: 40")
 
-    vargroup.add_argument("--var_filter_sap", default=60, type=int,
+    vargroup.add_argument("--var_filter_sap", default=-1, type=int,
                           help="Please define the strand balance probability"
                                "for the alternate allele (SAP)."
                                " The SAP is the Phred-scaled probability"
                                " that there is strand bias at the respective"
                                " site. A value near 0 indicates little or no"
-                               " strand bias. Default: 60")
+                               " strand bias."
+                               " For our use with Cleanplex TM Amplicons a strict"
+                               " filter of 60 sufficed. But we recieved reports"
+                               " of NimaGen Kit users, that reported missed variants"
+                               " and decided to ignore the filter per default."
+                               " Default: -1 meaning that no "
+                               " strand bias filtering is performed")
     vargroup.add_argument("--var_filter_qual", default=10, type=int,
                           help="Please define the minimal variant call"
                                " quality. Freebayes produces a general"
